Welcome to Hymn's documentation!
================================

Contents:

.. toctree::
  :maxdepth: 2

  intro
  examples
  api/index
  changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
